package com.bsz.school_send_back_end.controller;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.bsz.school_send_back_end.common.BaseResponse;
import com.bsz.school_send_back_end.common.ErrorCode;
import com.bsz.school_send_back_end.common.ResultUtils;
import com.bsz.school_send_back_end.exception.BusinessException;
import com.bsz.school_send_back_end.exception.ThrowUtils;
import com.bsz.school_send_back_end.model.domain.Systeminfo;
import com.bsz.school_send_back_end.model.dto.system.SystemAddRequest;
import com.bsz.school_send_back_end.model.dto.system.SystemDeleteRequest;
import com.bsz.school_send_back_end.model.dto.system.SystemQueryRequest;
import com.bsz.school_send_back_end.service.SysteminfoService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.BeanUtils;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.util.List;

@RestController
@Slf4j
@RequestMapping("/system")
public class SystemInfoController {

    @Resource
    private SysteminfoService systeminfoService;

    /**
     * 添加功能
     */
    @PostMapping("/add")
    public BaseResponse<Boolean> addInfo (@RequestBody SystemAddRequest systemAddRequest) {
        if (systemAddRequest == null) {
            throw new BusinessException(ErrorCode.PARAMS_ERROR);
        }
        Systeminfo systeminfo = new Systeminfo();
        BeanUtils.copyProperties(systemAddRequest, systeminfo);
        ThrowUtils.throwIf(systeminfo.getContent() == null, ErrorCode.PARAMS_ERROR, "内容为空");
        boolean save = systeminfoService.save(systeminfo);
        ThrowUtils.throwIf(!save, ErrorCode.OPERATION_ERROR);
        return ResultUtils.success(true, "添加成功");
    }

    /**
     * 删除功能
     */
    @PostMapping("/delete")
    public BaseResponse<Boolean> deleteInfo (@RequestBody SystemDeleteRequest deleteRequest) {
        if (deleteRequest == null) {
            throw new BusinessException(ErrorCode.PARAMS_ERROR);
        }

        boolean remove = systeminfoService.removeById(deleteRequest.getId());
        ThrowUtils.throwIf(!remove, ErrorCode.OPERATION_ERROR, "添加失败");
        return ResultUtils.success(true,"删除成功");
    }

    /**
     *查询列表
     */
    @PostMapping("/list")
    public BaseResponse<List<Systeminfo>> selectInfo (@RequestBody SystemQueryRequest common) {
        if (common == null) {
            throw new BusinessException(ErrorCode.PARAMS_ERROR);
        }

        LambdaQueryWrapper<Systeminfo> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(Systeminfo::getType, common.getType());
        List<Systeminfo> list = systeminfoService.list(queryWrapper);

        return ResultUtils.success(list,"查询成功");
    }
}
